@@ -70,7 +70,7 @@ apr_status_t block_DATE_GET_TIME(worker_t *worker, worker_t *parent, apr_pool_t
   const char *var = store_get(worker->params, "1");
 
   if (!var) {
-    worker_log_error(worker, "Need a variable name to store time");
+    worker_log(worker, LOG_ERR, "Need a variable name to store time");
   }
   
   worker_var_set(parent, var, apr_off_t_toa(worker->pbody, apr_time_as_msec(apr_time_now())));
@@ -200,7 +200,7 @@ apr_status_t block_DATE_TIMER(worker_t *worker, worker_t *parent,
     wconf->start_time = apr_time_now();
   }
   else {
-    worker_log_error(worker, "Timer command %s not implemented", cmd);
+    worker_log(worker, LOG_ERR, "Timer command %s not implemented", cmd);
   }
   return APR_SUCCESS;
 }
