@@ -4,13 +4,12 @@
 #include "stdio.h"
 #include "string.h"
 
-char *gbuf = NULL;
+int i = 0;
+
+const char *foo_test_val = NULL;
 
 static void* foo_custom_handle() {
-  if (!gbuf) {
-    gbuf = malloc(10000);
-  }
-  return gbuf;
+  return &i;
 }
 
 static apr_status_t foo_configure(void *custom, const char *buf) {
@@ -25,7 +24,12 @@ static apr_status_t foo_read(void *custom, char *buf, apr_size_t *len) {
 }
 
 static apr_status_t foo_read2(void *custom, char *buf, apr_size_t *len) {
+  /*
   const char *str = "GET / HTTP/1.1\r\n\r\n";
+  */
+  char str[1024];
+  ++i;
+  sprintf(str, "GET /%d HTTP/1.1 \r\n\r\n", i);
   *len = strlen(str);
   memcpy(buf, str, *len);
   return APR_SUCCESS;
@@ -35,6 +39,20 @@ static apr_status_t foo_write(void *custom, const char *buf, apr_size_t len) {
   return APR_SUCCESS;
 }
 
+apr_status_t foo_set(const char *string) {
+  foo_test_val = string;
+  return APR_SUCCESS;
+}
+
+apr_status_t foo_test(const char *string) {
+  if (foo_test_val && strcmp(string, foo_test_val) == 0) { 
+    return APR_SUCCESS;
+  }
+  else {
+    return APR_EINVAL;
+  }
+}
+
 transport_dso_t foo_front = {
   foo_custom_handle, 
   foo_configure, 
