@@ -31,6 +31,7 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
+#include <apr_version.h>
 #include "defines.h"
 
 /* Use STACK from openssl to sort commands */
@@ -49,18 +50,21 @@
 #include <apr_thread_proc.h>
 #include <apr_thread_cond.h>
 #include <apr_thread_mutex.h>
+#include <apr_pools.h>
 #include <apr_support.h>
 #include <apr_hash.h>
 #include <apr_base64.h>
 #include <apr_env.h>
 #include <apr_hooks.h>
 
-#include <pcre.h>
+#include <pcre/pcre.h>
 
 #if APR_HAVE_UNISTD_H
 #include <unistd.h> /* for getpid() */
 #endif
 
+#include <setjmp.h>
+
 #include "file.h"
 #include "appender_simple.h"
 #include "appender_std.h"
@@ -76,6 +80,7 @@
 #include "tcp_module.h"
 #include "body.h"
 
+
 /************************************************************************
  * Defines 
  ***********************************************************************/
@@ -487,6 +492,17 @@ int success = 1;
 /************************************************************************
  * Private 
  ***********************************************************************/
+#if OPENSSL_VERSION_NUMBER < 0x10100000
+
+#define sk_char_new(x)		SKM_sk_new(char, x)
+#define sk_char_push(x, y)	SKM_sk_push(char, x, y)
+#define sk_char_sort(x)		SKM_sk_sort(char, x)
+#define sk_char_pop(x)		SKM_sk_pop(char, x)
+
+#else
+
+DEFINE_STACK_OF(char);
+#endif
 
 static void worker_set_global_error(worker_t *worker); 
 static apr_status_t worker_interpret(worker_t * worker, worker_t *parent, 
@@ -695,6 +711,51 @@ static void worker_set_global_error(worker_t *worker) {
   unlock(worker->mutex);
 }
 
+static apr_status_t worker_local_call(worker_t *worker, worker_t *parent, 
+                                      char *line) {
+    apr_pool_t *ptmp;
+    apr_status_t status = APR_SUCCESS;
+
+    HT_POOL_CREATE(&ptmp);
+    {
+      if (worker_is_block(worker, line, ptmp)) {
+        status = command_CALL(NULL, worker, line, ptmp);
+        status = worker_check_error(parent, status);
+      }
+      else {
+        int j = 0;
+        command_t *command = lookup_command(local_commands, line);
+        if (command->flags & COMMAND_FLAGS_LINK) {
+          j += strlen(command->name);
+          status = command_CALL(NULL, worker, apr_pstrcat(worker->pbody, 
+                                command->syntax,
+                                " ", &line[j], NULL), 
+                                ptmp);
+          status = worker_check_error(parent, status);
+        }
+        else if (command->func) {
+          j += strlen(command->name);
+          status = command->func(command, worker, &line[j], ptmp);
+          status = worker_check_error(parent, status);
+        }
+        else {
+          status = command_CALL(NULL, worker, line, ptmp);
+          if (!APR_STATUS_IS_ENOENT(status)) {
+            status = worker_check_error(parent, status);
+          }
+          else {
+            worker_log(worker, LOG_ERR, "%s syntax error", worker->name);
+            worker_set_global_error(worker);
+            status = APR_EINVAL;
+          }
+        }
+      }
+    }
+    apr_pool_destroy(ptmp);
+
+    return status;
+}
+
 /**
  * Interpreter
  *
@@ -716,43 +777,9 @@ static apr_status_t worker_interpret(worker_t * worker, worker_t *parent,
 
   for (worker->cmd = worker->cmd_from; worker->cmd < to; worker->cmd++) {
     char *line;
-    apr_pool_t *ptmp;
 
-    apr_pool_create_unmanaged_ex(&ptmp, NULL, NULL);
     line = e[worker->cmd].val;
-    if (worker_is_block(worker, line, ptmp)) {
-      status = command_CALL(NULL, worker, line, ptmp);
-      status = worker_check_error(parent, status);
-    }
-    else {
-      int j = 0;
-      command_t *command = lookup_command(local_commands, line);
-      if (command->flags & COMMAND_FLAGS_LINK) {
-        j += strlen(command->name);
-        status = command_CALL(NULL, worker, apr_pstrcat(worker->pbody, 
-                              command->syntax,
-                              " ", &line[j], NULL), 
-                              ptmp);
-        status = worker_check_error(parent, status);
-      }
-      else if (command->func) {
-        j += strlen(command->name);
-        status = command->func(command, worker, &line[j], ptmp);
-        status = worker_check_error(parent, status);
-      }
-      else {
-        status = command_CALL(NULL, worker, line, ptmp);
-        if (!APR_STATUS_IS_ENOENT(status)) {
-          status = worker_check_error(parent, status);
-        }
-        else {
-          worker_log(worker, LOG_ERR, "%s syntax error", worker->name);
-          worker_set_global_error(worker);
-          status = APR_EINVAL;
-        }
-      }
-    }
-    apr_pool_destroy(ptmp);
+    status = worker_local_call(worker, parent, line);
 
     if (status != APR_SUCCESS) {
       return status;
@@ -1158,11 +1185,19 @@ static apr_status_t global_new(global_t **global, store_t *vars,
   appender_t *appender;
   apr_status_t status;
   apr_thread_mutex_t *mutex;
+  apr_allocator_t *allocator;
 
+  allocator = apr_pool_allocator_get(p);
+  if ((status = apr_thread_mutex_create(&mutex, APR_THREAD_MUTEX_DEFAULT,
+                                        p)) != APR_SUCCESS) {
+    apr_file_printf(err, "\n"
+               "Global creation: could not create mutex for global pool");
+    return status;
+  }
+  apr_allocator_mutex_set(allocator, mutex);
   *global = apr_pcalloc(p, sizeof(global_t));
-
   (*global)->pool = p;
-  apr_pool_create(&(*global)->cleanup_pool, NULL);
+  HT_POOL_CREATE(&(*global)->cleanup_pool);
   (*global)->config = apr_hash_make(p);
   (*global)->vars = vars;
 
@@ -1178,7 +1213,7 @@ static apr_status_t global_new(global_t **global, store_t *vars,
   if ((status = apr_thread_mutex_create(&mutex, APR_THREAD_MUTEX_DEFAULT,
                                         (*global)->pool)) != APR_SUCCESS) {
     apr_file_printf(err, "\n"
-               "Global creation: could not create sync mutex");
+               "Global creation: could not create mutex for appender");
     return status;
   }
 
@@ -1261,7 +1296,7 @@ static apr_status_t worker_file_cleanup(void *data) {
   const char *name = data;
   apr_pool_t *pool;
 
-  apr_pool_create(&pool, NULL);
+  HT_POOL_CREATE(&pool);
   apr_file_remove(name, pool);
   apr_pool_destroy(pool);
   return APR_SUCCESS;
@@ -2000,7 +2035,7 @@ static apr_status_t global_START(command_t *self, global_t *global, char *data,
     }
   }
   apr_table_clear(global->clients);
-   
+ 
   /* notify start threads */
   e = (apr_table_entry_t *) apr_table_elts(global->threads)->elts;
   for (i = 0; i < apr_table_elts(global->threads)->nelts; ++i) {
@@ -2011,6 +2046,7 @@ static apr_status_t global_START(command_t *self, global_t *global, char *data,
       return status;
     }
   }
+ 
   return APR_SUCCESS;
 }
 
@@ -2164,7 +2200,7 @@ static apr_status_t interpret_recursiv(apr_file_t *fp, global_t *global) {
 	/* replace all variables for global commands */
 	line = replacer(global->pool, &line[i], replacer_hook, global_replacer);
 
-        apr_pool_create_unmanaged_ex(&ptmp, NULL, NULL);
+        HT_POOL_CREATE(&ptmp);
 	/* lookup function index */
 	i = 0;
 	command = lookup_command(global_commands, line);
@@ -2175,12 +2211,8 @@ static apr_status_t interpret_recursiv(apr_file_t *fp, global_t *global) {
 	    return status;
 	  }
 	}
-        else { /* let's see if we find block for this job */
-          int cur_log_mode = logger_get_mode(global->worker->logger);
-
-          logger_set_mode(global->worker->logger, 1);
-          status = command_CALL(NULL, global->worker, line, ptmp);
-          logger_set_mode(global->worker->logger, cur_log_mode);
+        else { 
+          status = worker_local_call(global->worker, global->worker, line);
           if (status != APR_SUCCESS && !APR_STATUS_IS_ENOENT(status)) {
             return status;
           }
@@ -2354,7 +2386,7 @@ static void show_commands(apr_pool_t *p, global_t *global) {
   char *line;
 
   fprintf(stdout, "Global commands");
-  sorted = SKM_sk_new(char, commands_compare);
+  sorted = sk_char_new(commands_compare);
   for (i = 0; global_commands[i].name; i++) {
     if (global_commands[i].flags & COMMAND_FLAGS_DEPRECIATED) {
       line = apr_psprintf(p, "%s *DEPRECIATED*", 
@@ -2372,19 +2404,19 @@ static void show_commands(apr_pool_t *p, global_t *global) {
       line = apr_psprintf(p, "%s %s", global_commands[i].name, 
 			  global_commands[i].syntax);
     }
-    SKM_sk_push(char, sorted, line);
+    sk_char_push(sorted, line);
   }
-  SKM_sk_sort(char, sorted);
+  sk_char_sort(sorted);
 
-  line = SKM_sk_pop(char, sorted);  
+  line = sk_char_pop(sorted);
   while (line) {
     fprintf(stdout, "\n");
     fprintf(stdout, "\t%s", line);
-    line = SKM_sk_pop(char, sorted);  
+    line = sk_char_pop(sorted);
   }
 
   fprintf(stdout, "\n\nLocal commands");
-  sorted = SKM_sk_new(char, commands_compare);
+  sorted = sk_char_new(commands_compare);
   for (i = 0; local_commands[i].name; i++) {
     if (local_commands[i].flags & COMMAND_FLAGS_DEPRECIATED) {
       line = apr_psprintf(p, "*DEPRECIATED* %s", 
@@ -2402,19 +2434,19 @@ static void show_commands(apr_pool_t *p, global_t *global) {
       line = apr_psprintf(p, "%s %s", local_commands[i].name, 
 			  local_commands[i].syntax);
     }
-    SKM_sk_push(char, sorted, line);
+    sk_char_push(sorted, line);
   }
-  SKM_sk_sort(char, sorted);
+  sk_char_sort(sorted);
 
-  line = SKM_sk_pop(char, sorted);  
+  line = sk_char_pop(sorted);
   while (line) {
     fprintf(stdout, "\n");
     fprintf(stdout, "\t%s", line);
-    line = SKM_sk_pop(char, sorted);  
+    line = sk_char_pop(sorted);
   }
 
   fprintf(stdout, "\n\nModule commands");
-  sorted = SKM_sk_new(char, commands_compare);
+  sorted = sk_char_new(commands_compare);
   {
     apr_hash_index_t *hi;
     const char *module;
@@ -2437,19 +2469,19 @@ static void show_commands(apr_pool_t *p, global_t *global) {
               line = apr_psprintf(p, "%s:%s %s", module, command, 
                       worker->short_desc?worker->short_desc:"");
             }
-	    SKM_sk_push(char, sorted, line);
+	    sk_char_push(sorted, line);
 	  }
 	}
       }
     }
   }
-  SKM_sk_sort(char, sorted);
+  sk_char_sort(sorted);
 
-  line = SKM_sk_pop(char, sorted);  
+  line = sk_char_pop(sorted);
   while (line) {
     fprintf(stdout, "\n");
     fprintf(stdout, "\t%s", line);
-    line = SKM_sk_pop(char, sorted);  
+    line = sk_char_pop(sorted);
   }
 
   fprintf(stdout, "\n\n(Get detailed help with --help-command <command>)\n");
@@ -2598,7 +2630,7 @@ int main(int argc, const char *const argv[]) {
   srand(apr_time_now()); 
   
   apr_app_initialize(&argc, &argv, NULL);
-  apr_pool_create_unmanaged_ex(&pool, NULL, NULL);
+  HT_POOL_CREATE(&pool);
 
   /* block broken pipe signal */
 #if !defined(WIN32)
@@ -2612,8 +2644,8 @@ int main(int argc, const char *const argv[]) {
   /* create a global vars table */
   vars = store_make(pool);
 
-  apr_file_open_flags_stderr(&err, APR_BUFFERED|APR_XTHREAD, pool);
-  apr_file_open_flags_stdout(&out, APR_BUFFERED|APR_XTHREAD, pool);
+  HT_OPEN_STDERR(&err, APR_BUFFERED|APR_XTHREAD, pool);
+  HT_OPEN_STDOUT(&out, APR_BUFFERED|APR_XTHREAD, pool);
 
   /* get options */
   apr_getopt_init(&opt, pool, argc, argv);
