@@ -67,17 +67,17 @@ static apr_status_t block_MATH_EVAL(worker_t *worker, worker_t *parent,
   math_eval_t *eval_hook = math_eval_make(ptmp);
 
   if (!value) {
-    worker_log_error(worker, "Missing expression");
+    worker_log(worker, LOG_ERR, "Missing expression");
     return APR_EINVAL;
   }
 
   if (!var) {
-    worker_log_error(worker, "Missing variable");
+    worker_log(worker, LOG_ERR, "Missing variable");
     return APR_EINVAL;
   }
 
   if ((status = math_evaluate(eval_hook, expr, &val)) != APR_SUCCESS) {
-    worker_log_error(worker, "Expression \"%s\" not valid", expr);
+    worker_log(worker, LOG_ERR, "Expression \"%s\" not valid", expr);
     return status;
   }
 
