@@ -26,7 +26,6 @@ apr_status_t lua_module_init(global_t *global);
 apr_status_t dso_module_init(global_t *global);
 apr_status_t annotation_module_init(global_t *global);
 apr_status_t charset_module_init(global_t *global);
-apr_status_t perf_module_init(global_t *global);
 apr_status_t dbg_module_init(global_t *global);
 apr_status_t sys_module_init(global_t *global);
 apr_status_t math_module_init(global_t *global);
@@ -49,7 +48,6 @@ module_t modules[] = {
   { dso_module_init },
   { annotation_module_init },
   { charset_module_init },
-  { perf_module_init },
   { dbg_module_init },
   { sys_module_init },
   { math_module_init },
