@@ -141,7 +141,8 @@ static apr_status_t tcp_hook_connect(worker_t *worker) {
 
   transport_register(worker->socket, transport);
 
-  worker_log(worker, LOG_DEBUG, "tcp connect socket: %p transport: %p", worker->socket, transport);
+  worker_log(worker, LOG_DEBUG, "tcp connect socket: %"APR_UINT64_T_HEX_FMT" "
+             "transport: %"APR_UINT64_T_HEX_FMT, worker->socket, transport);
 
   return APR_SUCCESS;
 }
@@ -162,7 +163,8 @@ static apr_status_t tcp_hook_accept(worker_t *worker, char *data) {
 			    tcp_transport_write);
   transport_register(worker->socket, transport);
 
-  worker_log(worker, LOG_DEBUG, "tcp accept socket: %p transport: %p", worker->socket, transport);
+  worker_log(worker, LOG_DEBUG, "tcp accept socket: %"APR_UINT64_T_HEX_FMT" "
+             "transport: %"APR_UINT64_T_HEX_FMT, worker->socket, transport);
 
   return APR_SUCCESS;
 }
@@ -182,7 +184,7 @@ apr_status_t tcp_listen(worker_t *worker,  int backlog) {
   apr_sockaddr_t *local_addr;
   
   if (worker->listener) {
-    worker_log_error(worker, "Server allready up");
+    worker_log(worker, LOG_ERR, "Server allready up");
     return APR_EGENERAL;
   }
 
@@ -205,13 +207,13 @@ apr_status_t tcp_listen(worker_t *worker,  int backlog) {
   
   worker_log(worker, LOG_DEBUG, "--- bind");
   if ((status = apr_socket_bind(worker->listener, local_addr)) != APR_SUCCESS) {
-    worker_log_error(worker, "Could not bind");
+    worker_log(worker, LOG_ERR, "Could not bind");
     return status;
   }
 
   worker_log(worker, LOG_DEBUG, "--- listen");
   if ((status = apr_socket_listen(worker->listener, backlog)) != APR_SUCCESS) {
-    worker_log_error(worker, "Could not listen");
+    worker_log(worker, LOG_ERR, "Could not listen");
     return status;
   }
 
@@ -303,7 +305,7 @@ apr_status_t tcp_accept(worker_t *worker) {
 
   worker_log(worker, LOG_DEBUG, "--- accept");
   if (!worker->listener) {
-    worker_log_error(worker, "Server down");
+    worker_log(worker, LOG_ERR, "Server down");
     return APR_EGENERAL;
   }
 
@@ -313,6 +315,10 @@ apr_status_t tcp_accept(worker_t *worker) {
     worker->socket->socket = NULL;
     return status;
   }
+  if ((status = apr_socket_opt_set(worker->socket->socket, APR_TCP_NODELAY, 1)) 
+      != APR_SUCCESS) {
+    return status;
+  }
   if ((status =
          apr_socket_timeout_set(worker->socket->socket, worker->socktmo)) 
       != APR_SUCCESS) {
@@ -363,7 +369,7 @@ static apr_status_t block_TCP_LISTEN(worker_t * worker, worker_t *parent, apr_po
   char *backlog = store_get_copy(worker->params, ptmp, "2");
 
   if (!address) {
-    worker_log_error(worker, "no address specified");
+    worker_log(worker, LOG_ERR, "no address specified");
     status = APR_EINVAL;
   }
 
@@ -372,7 +378,7 @@ static apr_status_t block_TCP_LISTEN(worker_t * worker, worker_t *parent, apr_po
   if ((status = apr_parse_addr_port(&worker->listener_addr, &scope_id, 
 	                            &worker->listener_port, address, 
 				    worker->pbody)) != APR_SUCCESS) {
-    worker_log_error(worker, "Can not parse '%s'", address);
+    worker_log(worker, LOG_ERR, "Can not parse '%s'", address);
     return status;
   }
 
